@@ -120,6 +120,12 @@ def _find_linked_node(node_map: dict, node: dict):
 def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
 
 
+def _node_year(node: dict):
+    date = node.get('endDate', node.get('startDate'))
+    date = safe_parse_date(date) if date else None
+    return date.year if date else None
+
+
 def _import_model(name: str):
     return importlib.import_module(f"hestia_earth.models.{name}").run
 
