@@ -12,7 +12,7 @@ from .shared import (
 )
 from .input import validate_must_include_id
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
-from .product import validate_economicValueShare, validate_value as validate_product_value
+from .product import validate_economicValueShare, validate_value as validate_product_value, validate_excreta
 from .data_completeness import validate_dataCompleteness
 from .transformation import validate_previous_transformation, validate_first_transformation
 
@@ -196,7 +196,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_product_value(cycle.get('products')),
         validate_properties_default_value(cycle, 'products', 'properties'),
         validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
-        validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG)
+        validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
+        validate_excreta(cycle, 'products')
     ] if len(cycle.get('products', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'practices'),
         validate_list_dates_format(cycle, 'practices'),
