@@ -191,8 +191,8 @@ def validate_with_models(site: dict, list_key: str):
         value = blank_node.get('value', [0])
         value = list_sum(value, value)
         expected_value = MEASUREMENTS_MODELS[term_id](site, blank_node) if term_id in MEASUREMENTS_MODELS else value
-        delta = value_difference(value, expected_value)
-        return expected_value is None or delta < 0.25 or {
+        delta = value_difference(value, expected_value) if expected_value else 0
+        return delta < 0.25 or {
             'level': 'warning',
             'dataPath': f".{list_key}[{index}].value",
             'message': 'the measurement provided might be in error',
