@@ -11,8 +11,9 @@ from hestia_earth.utils.model import find_term_match
 from hestia_earth.validation.geojson import get_geojson_area
 from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id
 from hestia_earth.validation.utils import (
-    update_error_path, _filter_list_errors, _next_error, _same_properties, _value_average, _list_except_item,
-    _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key, _is_same_dict, _dict_without_key
+    update_error_path, _filter_list_errors, _next_error, _same_properties, _value_average,
+    _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key,
+    _list_except_item, _dict_without_key, _hash_dict
 )
 
 
@@ -80,7 +81,11 @@ def validate_list_dates_length(node: dict, list_key: str):
         return value is None or dates is None or len(dates) == len(value) or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].dates",
-            'message': 'must contain ' + str(len(value)) + (' values' if len(value) > 1 else ' value')
+            'message': 'must contain as many items as values',
+            'params': {
+                'expected': len(value),
+                'current': len(dates)
+            }
         }
 
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
@@ -120,13 +125,10 @@ def validate_list_min_max(node: dict, list_key: str):
     return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
-def validate_nodes_duplicates(node: dict, values: List[dict]):
+def validate_nodes_duplicates(node: dict, node_by_hash: dict):
     node_without_id = _dict_without_key(node, 'id')
-    other_values = _list_except_item(values, node)
-    duplicates = [
-        value for value in other_values if node.get('type') == value.get('type') and
-        _is_same_dict(node_without_id, _dict_without_key(value, 'id'))
-    ]
+    key = _hash_dict(node_without_id)
+    duplicates = _list_except_item(node_by_hash.get(key, []), node)
     return [next(
         ({
             'level': 'warning',
@@ -280,8 +282,8 @@ def validate_empty_fields(node: dict):
     return _filter_list_errors(map(validate, keys), False)
 
 
-def validate_linked_source_privacy(node: dict, key: str, nodes: list):
-    related_source = _find_linked_node(nodes, node.get(key, {}))
+def validate_linked_source_privacy(node: dict, key: str, node_map: dict):
+    related_source = _find_linked_node(node_map, node.get(key, {}))
     node_privacy = node.get('dataPrivate')
     related_source_privacy = related_source.get('dataPrivate') if related_source else None
     return related_source_privacy is None or node_privacy == related_source_privacy or {
