@@ -3,8 +3,9 @@ import json
 from hestia_earth.schema import SiteSiteType, TermTermType
 
 from tests.utils import fixtures_path
-from hestia_earth.validation.validators.data_completeness import validate_dataCompleteness, _validate_all_values, \
-    _validate_site_type
+from hestia_earth.validation.validators.data_completeness import (
+    validate_dataCompleteness, _validate_all_values, _validate_site_type
+)
 
 
 def test_validate_dataCompleteness_valid():
@@ -16,7 +17,7 @@ def test_validate_dataCompleteness_valid():
 def test_validate_all_values_valid():
     with open(f"{fixtures_path}/dataCompleteness/valid.json") as f:
         data = json.load(f)
-    assert _validate_all_values(data)
+    assert _validate_all_values(data) is True
 
 
 def test_validate_all_values_warning():
@@ -34,12 +35,12 @@ def test_validate_site_type_valid():
         site = json.load(f)
     with open(f"{fixtures_path}/dataCompleteness/site-type/valid.json") as f:
         data = json.load(f)
-    assert _validate_site_type(data, site)
+    assert _validate_site_type(data, site) is True
 
     # also works if siteType is not cropland
-    site['siteType'] = SiteSiteType.POND.value
+    site['siteType'] = SiteSiteType.LAKE.value
     data[TermTermType.EXCRETAMANAGEMENT.value] = False
-    assert _validate_site_type(data, site)
+    assert _validate_site_type(data, site) is True
 
 
 def test_validate_site_type_warning():
